[llvm-commits] CVS: llvm/include/llvm/AbstractTypeUser.h Argument.h BasicBlock.h CallGraphSCCPass.h Constant.h ConstantHandling.h Constants.h DerivedTypes.h Function.h GlobalValue.h GlobalVariable.h InstrTypes.h Instruction.def Instruction.h Intrinsics.h Module.h ModuleProvider.h Pass.h PassAnalysisSupport.h PassManager.h PassSupport.h SlotCalculator.h SymbolTable.h SymbolTableListTraits.h Type.def Type.h Use.h User.h Value.h iMemory.h iOperators.h iOther.h iPHINode.h iTerminators.h

Brian Gaeke gaeke at cs.uiuc.edu
Tue Nov 11 16:46:24 PST 2003


Changes in directory llvm/include/llvm:

AbstractTypeUser.h updated: 1.16 -> 1.17
Argument.h updated: 1.6 -> 1.7
BasicBlock.h updated: 1.34 -> 1.35
CallGraphSCCPass.h updated: 1.2 -> 1.3
Constant.h updated: 1.11 -> 1.12
ConstantHandling.h updated: 1.31 -> 1.32
Constants.h updated: 1.33 -> 1.34
DerivedTypes.h updated: 1.46 -> 1.47
Function.h updated: 1.48 -> 1.49
GlobalValue.h updated: 1.12 -> 1.13
GlobalVariable.h updated: 1.24 -> 1.25
InstrTypes.h updated: 1.33 -> 1.34
Instruction.def updated: 1.11 -> 1.12
Instruction.h updated: 1.48 -> 1.49
Intrinsics.h updated: 1.12 -> 1.13
Module.h updated: 1.37 -> 1.38
ModuleProvider.h updated: 1.6 -> 1.7
Pass.h updated: 1.41 -> 1.42
PassAnalysisSupport.h updated: 1.16 -> 1.17
PassManager.h updated: 1.10 -> 1.11
PassSupport.h updated: 1.16 -> 1.17
SlotCalculator.h updated: 1.12 -> 1.13
SymbolTable.h updated: 1.28 -> 1.29
SymbolTableListTraits.h updated: 1.3 -> 1.4
Type.def updated: 1.5 -> 1.6
Type.h updated: 1.36 -> 1.37
Use.h updated: 1.2 -> 1.3
User.h updated: 1.26 -> 1.27
Value.h updated: 1.47 -> 1.48
iMemory.h updated: 1.41 -> 1.42
iOperators.h updated: 1.14 -> 1.15
iOther.h updated: 1.40 -> 1.41
iPHINode.h updated: 1.13 -> 1.14
iTerminators.h updated: 1.33 -> 1.34

---
Log message:

Put all LLVM code into the llvm namespace, as per bug 109.

---
Diffs of the changes:  (+147 -8)

Index: llvm/include/llvm/AbstractTypeUser.h
diff -u llvm/include/llvm/AbstractTypeUser.h:1.16 llvm/include/llvm/AbstractTypeUser.h:1.17
--- llvm/include/llvm/AbstractTypeUser.h:1.16	Mon Oct 20 15:19:13 2003
+++ llvm/include/llvm/AbstractTypeUser.h	Tue Nov 11 16:41:29 2003
@@ -37,6 +37,8 @@
 //
 #include <cassert>
 
+namespace llvm {
+
 class Type;
 class DerivedType;
 
@@ -164,5 +166,7 @@
   void addRef();
   void dropRef();
 };
+
+} // End llvm namespace
 
 #endif


Index: llvm/include/llvm/Argument.h
diff -u llvm/include/llvm/Argument.h:1.6 llvm/include/llvm/Argument.h:1.7
--- llvm/include/llvm/Argument.h:1.6	Mon Oct 20 15:19:13 2003
+++ llvm/include/llvm/Argument.h	Tue Nov 11 16:41:29 2003
@@ -17,6 +17,8 @@
 
 #include "llvm/Value.h"
 
+namespace llvm {
+
 class Argument : public Value {  // Defined in the Function.cpp file
   Function *Parent;
 
@@ -55,5 +57,7 @@
     return V->getValueType() == ArgumentVal;
   }
 };
+
+} // End llvm namespace
 
 #endif


Index: llvm/include/llvm/BasicBlock.h
diff -u llvm/include/llvm/BasicBlock.h:1.34 llvm/include/llvm/BasicBlock.h:1.35
--- llvm/include/llvm/BasicBlock.h:1.34	Thu Oct 30 17:41:19 2003
+++ llvm/include/llvm/BasicBlock.h	Tue Nov 11 16:41:29 2003
@@ -33,6 +33,8 @@
 #include "llvm/SymbolTableListTraits.h"
 #include "Support/ilist"
 
+namespace llvm {
+
 class TerminatorInst;
 template <class _Term, class _BB> class SuccIterator;  // Successor Iterator
 template <class _Ptr, class _USE_iterator> class PredIterator;
@@ -170,5 +172,7 @@
   ///
   BasicBlock *splitBasicBlock(iterator I, const std::string &BBName = "");
 };
+
+} // End llvm namespace
 
 #endif


Index: llvm/include/llvm/CallGraphSCCPass.h
diff -u llvm/include/llvm/CallGraphSCCPass.h:1.2 llvm/include/llvm/CallGraphSCCPass.h:1.3
--- llvm/include/llvm/CallGraphSCCPass.h:1.2	Mon Oct 20 15:19:13 2003
+++ llvm/include/llvm/CallGraphSCCPass.h	Tue Nov 11 16:41:29 2003
@@ -23,6 +23,8 @@
 
 #include "llvm/Pass.h"
 
+namespace llvm {
+
 class CallGraphNode;
 
 struct CallGraphSCCPass : public Pass {
@@ -45,5 +47,7 @@
   /// always explicitly call the implementation here.
   virtual void getAnalysisUsage(AnalysisUsage &Info) const;
 };
+
+} // End llvm namespace
 
 #endif


Index: llvm/include/llvm/Constant.h
diff -u llvm/include/llvm/Constant.h:1.11 llvm/include/llvm/Constant.h:1.12
--- llvm/include/llvm/Constant.h:1.11	Mon Oct 20 15:19:13 2003
+++ llvm/include/llvm/Constant.h	Tue Nov 11 16:41:29 2003
@@ -16,6 +16,8 @@
 
 #include "llvm/User.h"
 
+namespace llvm {
+
 class Constant : public User {
 protected:
   inline Constant(const Type *Ty) : User(Ty, Value::ConstantVal) {}
@@ -90,5 +92,7 @@
   unsigned mutateReferences(Value* OldV, Value *NewV);
   // END WARNING!!
 };
+
+} // End llvm namespace
 
 #endif


Index: llvm/include/llvm/ConstantHandling.h
diff -u llvm/include/llvm/ConstantHandling.h:1.31 llvm/include/llvm/ConstantHandling.h:1.32
--- llvm/include/llvm/ConstantHandling.h:1.31	Tue Nov  4 17:37:40 2003
+++ llvm/include/llvm/ConstantHandling.h	Tue Nov 11 16:41:29 2003
@@ -42,6 +42,9 @@
 
 #include "llvm/Constants.h"
 #include "llvm/Type.h"
+
+namespace llvm {
+
 class PointerType;
 
 //===----------------------------------------------------------------------===//
@@ -244,4 +247,7 @@
                                        const Constant *V2);
 Constant *ConstantFoldGetElementPtr(const Constant *C,
                                     const std::vector<Constant*> &IdxList);
+
+} // End llvm namespace
+
 #endif


Index: llvm/include/llvm/Constants.h
diff -u llvm/include/llvm/Constants.h:1.33 llvm/include/llvm/Constants.h:1.34
--- llvm/include/llvm/Constants.h:1.33	Mon Oct 20 15:19:13 2003
+++ llvm/include/llvm/Constants.h	Tue Nov 11 16:41:29 2003
@@ -18,6 +18,8 @@
 #include "llvm/Constant.h"
 #include "Support/DataTypes.h"
 
+namespace llvm {
+
 class ArrayType;
 class StructType;
 class PointerType;
@@ -574,5 +576,7 @@
     return isa<Constant>(V) && classof(cast<Constant>(V));
   }
 };
+
+} // End llvm namespace
 
 #endif


Index: llvm/include/llvm/DerivedTypes.h
diff -u llvm/include/llvm/DerivedTypes.h:1.46 llvm/include/llvm/DerivedTypes.h:1.47
--- llvm/include/llvm/DerivedTypes.h:1.46	Mon Oct 20 15:19:14 2003
+++ llvm/include/llvm/DerivedTypes.h	Tue Nov 11 16:41:29 2003
@@ -21,6 +21,8 @@
 #include "llvm/Type.h"
 #include <vector>
 
+namespace llvm {
+
 template<class ValType, class TypeClass> class TypeMap;
 class FunctionValType;
 class ArrayValType;
@@ -489,5 +491,7 @@
   if (!NewTy) return Ty;
   return *const_cast<PATypeHolder*>(this) = NewTy;
 }
+
+} // End llvm namespace
 
 #endif


Index: llvm/include/llvm/Function.h
diff -u llvm/include/llvm/Function.h:1.48 llvm/include/llvm/Function.h:1.49
--- llvm/include/llvm/Function.h:1.48	Thu Oct 30 17:41:19 2003
+++ llvm/include/llvm/Function.h	Tue Nov 11 16:41:29 2003
@@ -22,6 +22,8 @@
 #include "llvm/BasicBlock.h"
 #include "llvm/Argument.h"
 
+namespace llvm {
+
 class FunctionType;
 
 // Traits for intrusive list of instructions...
@@ -95,7 +97,7 @@
   virtual bool isExternal() const { return BasicBlocks.empty(); }
 
   /// getIntrinsicID - This method returns the ID number of the specified
-  /// function, or LLVMIntrinsic::not_intrinsic if the function is not an
+  /// function, or Intrinsic::not_intrinsic if the function is not an
   /// instrinsic, or if the pointer is null.  This value is always defined to be
   /// zero to allow easy checking for whether a function is intrinsic or not.
   /// The particular intrinsic functions which correspond to this value are
@@ -219,5 +221,7 @@
   ///
   void dropAllReferences();
 };
+
+} // End llvm namespace
 
 #endif


Index: llvm/include/llvm/GlobalValue.h
diff -u llvm/include/llvm/GlobalValue.h:1.12 llvm/include/llvm/GlobalValue.h:1.13
--- llvm/include/llvm/GlobalValue.h:1.12	Mon Oct 20 15:19:14 2003
+++ llvm/include/llvm/GlobalValue.h	Tue Nov 11 16:41:29 2003
@@ -18,6 +18,9 @@
 #define LLVM_GLOBALVALUE_H
 
 #include "llvm/User.h"
+
+namespace llvm {
+
 class PointerType;
 class Module;
 
@@ -70,5 +73,7 @@
            V->getValueType() == Value::GlobalVariableVal;
   }
 };
+
+} // End llvm namespace
 
 #endif


Index: llvm/include/llvm/GlobalVariable.h
diff -u llvm/include/llvm/GlobalVariable.h:1.24 llvm/include/llvm/GlobalVariable.h:1.25
--- llvm/include/llvm/GlobalVariable.h:1.24	Mon Oct 20 15:19:14 2003
+++ llvm/include/llvm/GlobalVariable.h	Tue Nov 11 16:41:29 2003
@@ -22,6 +22,8 @@
 
 #include "llvm/GlobalValue.h"
 
+namespace llvm {
+
 class Module;
 class Constant;
 class PointerType;
@@ -104,5 +106,7 @@
     return V->getValueType() == Value::GlobalVariableVal;
   }
 };
+
+} // End llvm namespace
 
 #endif


Index: llvm/include/llvm/InstrTypes.h
diff -u llvm/include/llvm/InstrTypes.h:1.33 llvm/include/llvm/InstrTypes.h:1.34
--- llvm/include/llvm/InstrTypes.h:1.33	Mon Oct 20 15:19:14 2003
+++ llvm/include/llvm/InstrTypes.h	Tue Nov 11 16:41:29 2003
@@ -18,6 +18,8 @@
 
 #include "llvm/Instruction.h"
 
+namespace llvm {
+
 //===----------------------------------------------------------------------===//
 //                            TerminatorInst Class
 //===----------------------------------------------------------------------===//
@@ -133,5 +135,7 @@
     return isa<Instruction>(V) && classof(cast<Instruction>(V));
   }
 };
+
+} // End llvm namespace
 
 #endif


Index: llvm/include/llvm/Instruction.def
diff -u llvm/include/llvm/Instruction.def:1.11 llvm/include/llvm/Instruction.def:1.12
--- llvm/include/llvm/Instruction.def:1.11	Mon Oct 20 15:19:14 2003
+++ llvm/include/llvm/Instruction.def	Tue Nov 11 16:41:29 2003
@@ -15,7 +15,7 @@
 
 // NOTE: NO INCLUDE GUARD DESIRED!
 
-// Provide definitions of macros so that users of this file don't have to define
+// Provide definitions of macros so that users of this file do not have to define
 // everything to use it...
 //
 #ifndef FIRST_TERM_INST


Index: llvm/include/llvm/Instruction.h
diff -u llvm/include/llvm/Instruction.h:1.48 llvm/include/llvm/Instruction.h:1.49
--- llvm/include/llvm/Instruction.h:1.48	Thu Oct 30 17:41:19 2003
+++ llvm/include/llvm/Instruction.h	Tue Nov 11 16:41:30 2003
@@ -17,6 +17,8 @@
 
 #include "llvm/User.h"
 
+namespace llvm {
+
 class AssemblyAnnotationWriter;
 
 template<typename SC> struct ilist_traits;
@@ -150,5 +152,7 @@
 #include "llvm/Instruction.def"
   };
 };
+
+} // End llvm namespace
 
 #endif


Index: llvm/include/llvm/Module.h
diff -u llvm/include/llvm/Module.h:1.37 llvm/include/llvm/Module.h:1.38
--- llvm/include/llvm/Module.h:1.37	Thu Oct 30 17:41:19 2003
+++ llvm/include/llvm/Module.h	Tue Nov 11 16:41:30 2003
@@ -21,6 +21,9 @@
 
 #include "llvm/Function.h"
 #include "llvm/GlobalVariable.h"
+
+namespace llvm {
+
 class GlobalVariable;
 class GlobalValueRefMap;   // Used by ConstantVals.cpp
 class ConstantPointerRef;
@@ -212,5 +215,7 @@
   M.print(O);
   return O;
 }
+
+} // End llvm namespace
 
 #endif


Index: llvm/include/llvm/ModuleProvider.h
diff -u llvm/include/llvm/ModuleProvider.h:1.6 llvm/include/llvm/ModuleProvider.h:1.7
--- llvm/include/llvm/ModuleProvider.h:1.6	Mon Oct 20 15:19:14 2003
+++ llvm/include/llvm/ModuleProvider.h	Tue Nov 11 16:41:30 2003
@@ -18,6 +18,8 @@
 #ifndef MODULEPROVIDER_H
 #define MODULEPROVIDER_H
 
+namespace llvm {
+
 class Function;
 class Module;
 
@@ -51,5 +53,7 @@
     return tempM; 
   }
 };
+
+} // End llvm namespace
 
 #endif


Index: llvm/include/llvm/Pass.h
diff -u llvm/include/llvm/Pass.h:1.41 llvm/include/llvm/Pass.h:1.42
--- llvm/include/llvm/Pass.h:1.41	Mon Oct 20 15:19:14 2003
+++ llvm/include/llvm/Pass.h	Tue Nov 11 16:41:30 2003
@@ -34,6 +34,9 @@
 #include <iosfwd>
 #include <typeinfo>
 #include <cassert>
+
+namespace llvm {
+
 class Value;
 class BasicBlock;
 class Function;
@@ -328,6 +331,8 @@
   virtual void addToPassManager(PassManagerT<Function> *PM, AnalysisUsage &AU);
   virtual void addToPassManager(PassManagerT<BasicBlock> *PM,AnalysisUsage &AU);
 };
+
+} // End llvm namespace
 
 // Include support files that contain important APIs commonly used by Passes,
 // but that we want to separate out to make it easier to read the header files.


Index: llvm/include/llvm/PassAnalysisSupport.h
diff -u llvm/include/llvm/PassAnalysisSupport.h:1.16 llvm/include/llvm/PassAnalysisSupport.h:1.17
--- llvm/include/llvm/PassAnalysisSupport.h:1.16	Mon Oct 20 15:19:14 2003
+++ llvm/include/llvm/PassAnalysisSupport.h	Tue Nov 11 16:41:30 2003
@@ -19,6 +19,8 @@
 #ifndef LLVM_PASS_ANALYSIS_SUPPORT_H
 #define LLVM_PASS_ANALYSIS_SUPPORT_H
 
+namespace llvm {
+
 // No need to include Pass.h, we are being included by it!
 
 //===----------------------------------------------------------------------===//
@@ -132,5 +134,7 @@
   if (PI == 0) return 0;
   return dynamic_cast<AnalysisType*>(Resolver->getAnalysisToUpdate(PI));
 }
+
+} // End llvm namespace
 
 #endif


Index: llvm/include/llvm/PassManager.h
diff -u llvm/include/llvm/PassManager.h:1.10 llvm/include/llvm/PassManager.h:1.11
--- llvm/include/llvm/PassManager.h:1.10	Mon Oct 20 15:19:14 2003
+++ llvm/include/llvm/PassManager.h	Tue Nov 11 16:41:30 2003
@@ -17,6 +17,8 @@
 #ifndef LLVM_PASSMANAGER_H
 #define LLVM_PASSMANAGER_H
 
+namespace llvm {
+
 class Pass;
 class Module;
 class ModuleProvider;
@@ -71,5 +73,7 @@
   ///
   bool run(Function &F);
 };
+
+} // End llvm namespace
 
 #endif


Index: llvm/include/llvm/PassSupport.h
diff -u llvm/include/llvm/PassSupport.h:1.16 llvm/include/llvm/PassSupport.h:1.17
--- llvm/include/llvm/PassSupport.h:1.16	Fri Nov  7 12:56:32 2003
+++ llvm/include/llvm/PassSupport.h	Tue Nov 11 16:41:30 2003
@@ -23,6 +23,8 @@
 
 // No need to include Pass.h, we are being included by it!
 
+namespace llvm {
+
 class TargetMachine;
 
 //===---------------------------------------------------------------------------
@@ -395,4 +397,7 @@
 struct IncludeFile {
   IncludeFile(void *);
 };
+
+} // End llvm namespace
+
 #endif


Index: llvm/include/llvm/SlotCalculator.h
diff -u llvm/include/llvm/SlotCalculator.h:1.12 llvm/include/llvm/SlotCalculator.h:1.13
--- llvm/include/llvm/SlotCalculator.h:1.12	Mon Oct 20 15:19:14 2003
+++ llvm/include/llvm/SlotCalculator.h	Tue Nov 11 16:41:30 2003
@@ -22,6 +22,9 @@
 
 #include <vector>
 #include <map>
+
+namespace llvm {
+
 class Value;
 class Module;
 class Function;
@@ -91,5 +94,7 @@
   void processSymbolTable(const SymbolTable *ST);
   void processSymbolTableConstants(const SymbolTable *ST);
 };
+
+} // End llvm namespace
 
 #endif


Index: llvm/include/llvm/SymbolTable.h
diff -u llvm/include/llvm/SymbolTable.h:1.28 llvm/include/llvm/SymbolTable.h:1.29
--- llvm/include/llvm/SymbolTable.h:1.28	Sun Nov  9 13:39:48 2003
+++ llvm/include/llvm/SymbolTable.h	Tue Nov 11 16:41:30 2003
@@ -26,6 +26,8 @@
 #include "llvm/Value.h"
 #include <map>
 
+namespace llvm {
+
 class SymbolTable : public AbstractTypeUser,
 		    public std::map<const Type *, 
                                     std::map<const std::string, Value *> > {
@@ -131,5 +133,7 @@
   virtual void refineAbstractType(const DerivedType *OldTy, const Type *NewTy);
   virtual void typeBecameConcrete(const DerivedType *AbsTy);
 };
+
+} // End llvm namespace
 
 #endif


Index: llvm/include/llvm/SymbolTableListTraits.h
diff -u llvm/include/llvm/SymbolTableListTraits.h:1.3 llvm/include/llvm/SymbolTableListTraits.h:1.4
--- llvm/include/llvm/SymbolTableListTraits.h:1.3	Mon Oct 20 15:19:14 2003
+++ llvm/include/llvm/SymbolTableListTraits.h	Tue Nov 11 16:41:30 2003
@@ -25,6 +25,8 @@
 #ifndef LLVM_SYMBOLTABLELISTTRAITS_H
 #define LLVM_SYMBOLTABLELISTTRAITS_H
 
+namespace llvm {
+
 template<typename NodeTy> class ilist_iterator;
 template<typename NodeTy, typename Traits> class iplist;
 template<typename Ty> struct ilist_traits;
@@ -71,5 +73,7 @@
   void setItemParent(ItemParentClass *IP) { ItemParent = IP; }//This is private!
   void setParent(SymTabClass *Parent);  // This is private!
 };
+
+} // End llvm namespace
 
 #endif


Index: llvm/include/llvm/Type.def
diff -u llvm/include/llvm/Type.def:1.5 llvm/include/llvm/Type.def:1.6
--- llvm/include/llvm/Type.def:1.5	Mon Oct 20 15:19:14 2003
+++ llvm/include/llvm/Type.def	Tue Nov 11 16:41:30 2003
@@ -16,7 +16,7 @@
 // NOTE: NO INCLUDE GUARD DESIRED!
 
 
-// If the user didn't specify one of the macros, give a default noop defn.
+// If the user did not specify one of the macros, give a default noop defn.
 //
 #ifndef HANDLE_PRIM_TYPE
 #define HANDLE_PRIM_TYPE(x,y)


Index: llvm/include/llvm/Type.h
diff -u llvm/include/llvm/Type.h:1.36 llvm/include/llvm/Type.h:1.37
--- llvm/include/llvm/Type.h:1.36	Wed Oct 29 19:38:41 2003
+++ llvm/include/llvm/Type.h	Tue Nov 11 16:41:30 2003
@@ -37,6 +37,8 @@
 #include "Support/GraphTraits.h"
 #include "Support/iterator"
 
+namespace llvm {
+
 class DerivedType;
 class FunctionType;
 class ArrayType;
@@ -323,5 +325,7 @@
 template <> inline bool isa_impl<PointerType, Type>(const Type &Ty) { 
   return Ty.getPrimitiveID() == Type::PointerTyID;
 }
+
+} // End llvm namespace
 
 #endif


Index: llvm/include/llvm/Use.h
diff -u llvm/include/llvm/Use.h:1.2 llvm/include/llvm/Use.h:1.3
--- llvm/include/llvm/Use.h:1.2	Mon Oct 20 15:19:15 2003
+++ llvm/include/llvm/Use.h	Tue Nov 11 16:41:30 2003
@@ -17,6 +17,9 @@
 #define LLVM_USE_H
 
 #include "Support/ilist"
+
+namespace llvm {
+
 template<typename NodeTy> struct ilist_traits;
 class Value;
 class User;
@@ -77,13 +80,13 @@
 };
 
 
-template<> struct simplify_type<Use> {
+template<> struct std::simplify_type<Use> {
   typedef Value* SimpleType;
   static SimpleType getSimplifiedValue(const Use &Val) {
     return (SimpleType)Val.get();
   }
 };
-template<> struct simplify_type<const Use> {
+template<> struct std::simplify_type<const Use> {
   typedef Value* SimpleType;
   static SimpleType getSimplifiedValue(const Use &Val) {
     return (SimpleType)Val.get();
@@ -149,5 +152,7 @@
     return tmp;
   }
 };
+
+} // End llvm namespace
 
 #endif


Index: llvm/include/llvm/User.h
diff -u llvm/include/llvm/User.h:1.26 llvm/include/llvm/User.h:1.27
--- llvm/include/llvm/User.h:1.26	Mon Oct 20 15:19:15 2003
+++ llvm/include/llvm/User.h	Tue Nov 11 16:41:30 2003
@@ -22,6 +22,8 @@
 #include "llvm/Value.h"
 #include <vector>
 
+namespace llvm {
+
 class User : public Value {
   User(const User &);             // Do not implement
 protected:
@@ -109,5 +111,7 @@
 };
 template<> struct simplify_type<const User::const_op_iterator>
   : public simplify_type<User::const_op_iterator> {};
+
+} // End llvm namespace
 
 #endif


Index: llvm/include/llvm/Value.h
diff -u llvm/include/llvm/Value.h:1.47 llvm/include/llvm/Value.h:1.48
--- llvm/include/llvm/Value.h:1.47	Mon Oct 20 15:19:15 2003
+++ llvm/include/llvm/Value.h	Tue Nov 11 16:41:30 2003
@@ -23,6 +23,8 @@
 #include "Support/Casting.h"
 #include <iostream>
 
+namespace llvm {
+
 class Type;
 class Constant;
 class Argument;
@@ -197,5 +199,7 @@
 template <> inline bool isa_impl<GlobalValue, Value>(const Value &Val) { 
   return isa<GlobalVariable>(Val) || isa<Function>(Val);
 }
+
+} // End llvm namespace
 
 #endif


Index: llvm/include/llvm/iMemory.h
diff -u llvm/include/llvm/iMemory.h:1.41 llvm/include/llvm/iMemory.h:1.42
--- llvm/include/llvm/iMemory.h:1.41	Mon Oct 20 15:19:15 2003
+++ llvm/include/llvm/iMemory.h	Tue Nov 11 16:41:30 2003
@@ -16,6 +16,9 @@
 #define LLVM_IMEMORY_H
 
 #include "llvm/Instruction.h"
+
+namespace llvm {
+
 class PointerType;
 
 //===----------------------------------------------------------------------===//
@@ -295,5 +298,7 @@
     return isa<Instruction>(V) && classof(cast<Instruction>(V));
   }
 };
+
+} // End llvm namespace
 
 #endif // LLVM_IMEMORY_H


Index: llvm/include/llvm/iOperators.h
diff -u llvm/include/llvm/iOperators.h:1.14 llvm/include/llvm/iOperators.h:1.15
--- llvm/include/llvm/iOperators.h:1.14	Mon Oct 20 15:19:15 2003
+++ llvm/include/llvm/iOperators.h	Tue Nov 11 16:41:30 2003
@@ -16,6 +16,8 @@
 
 #include "llvm/InstrTypes.h"
 
+namespace llvm {
+
 /// SetCondInst class - Represent a setCC operator, where CC is eq, ne, lt, gt,
 /// le, or ge.
 ///
@@ -62,5 +64,7 @@
     return isa<Instruction>(V) && classof(cast<Instruction>(V));
   }
 };
+
+} // End llvm namespace
 
 #endif


Index: llvm/include/llvm/iOther.h
diff -u llvm/include/llvm/iOther.h:1.40 llvm/include/llvm/iOther.h:1.41
--- llvm/include/llvm/iOther.h:1.40	Fri Oct 31 11:51:02 2003
+++ llvm/include/llvm/iOther.h	Tue Nov 11 16:41:30 2003
@@ -17,6 +17,8 @@
 
 #include "llvm/InstrTypes.h"
 
+namespace llvm {
+
 //===----------------------------------------------------------------------===//
 //                                 CastInst Class
 //===----------------------------------------------------------------------===//
@@ -194,5 +196,7 @@
     return isa<Instruction>(V) && classof(cast<Instruction>(V));
   }
 };
+
+} // End llvm namespace
 
 #endif


Index: llvm/include/llvm/iPHINode.h
diff -u llvm/include/llvm/iPHINode.h:1.13 llvm/include/llvm/iPHINode.h:1.14
--- llvm/include/llvm/iPHINode.h:1.13	Mon Oct 20 15:19:15 2003
+++ llvm/include/llvm/iPHINode.h	Tue Nov 11 16:41:30 2003
@@ -15,6 +15,9 @@
 #define LLVM_IPHINODE_H
 
 #include "llvm/Instruction.h"
+
+namespace llvm {
+
 class BasicBlock;
 
 //===----------------------------------------------------------------------===//
@@ -111,5 +114,7 @@
     return isa<Instruction>(V) && classof(cast<Instruction>(V));
   }
 };
+
+} // End llvm namespace
 
 #endif


Index: llvm/include/llvm/iTerminators.h
diff -u llvm/include/llvm/iTerminators.h:1.33 llvm/include/llvm/iTerminators.h:1.34
--- llvm/include/llvm/iTerminators.h:1.33	Fri Oct 31 11:51:02 2003
+++ llvm/include/llvm/iTerminators.h	Tue Nov 11 16:41:30 2003
@@ -18,6 +18,8 @@
 
 #include "llvm/InstrTypes.h"
 
+namespace llvm {
+
 //===---------------------------------------------------------------------------
 // ReturnInst - Return a value (possibly void), from a function.  Execution does
 //              not continue in this function any longer.
@@ -305,5 +307,7 @@
     return isa<Instruction>(V) && classof(cast<Instruction>(V));
   }
 };
+
+} // End llvm namespace
 
 #endif





More information about the llvm-commits mailing list
Index: llvm/include/llvm/Intrinsics.h
diff -u llvm/include/llvm/Intrinsics.h:1.12 llvm/include/llvm/Intrinsics.h:1.13
--- llvm/include/llvm/Intrinsics.h:1.12	Mon Oct 20 15:19:14 2003
+++ llvm/include/llvm/Intrinsics.h	Tue Nov 11 16:41:30 2003
@@ -16,11 +16,13 @@
 #ifndef LLVM_INTRINSICS_H
 #define LLVM_INTRINSICS_H
 
-/// LLVMIntrinsic Namespace - This namespace contains an enum with a value for
+namespace llvm {
+
+/// Intrinsic Namespace - This namespace contains an enum with a value for
 /// every intrinsic/builtin function known by LLVM.  These enum values are
 /// returned by Function::getIntrinsicID().
 ///
-namespace LLVMIntrinsic {
+namespace Intrinsic {
   enum ID {
     not_intrinsic = 0,   // Must be zero
 
@@ -125,6 +127,9 @@
                     // second parameter, the possible values for which are
                     // defined in the AlphaSfpToSq enumeration
   };
-}
+
+} // End Intrinsic namespace
+
+} // End llvm namespace
 
 #endif

